@@ -24,10 +24,10 @@ private slots:
     void on_saveButton_clicked();
     void on_restoreButton_clicked();
     void on_cancelButton_clicked();
-    void on_downloadsDirButton_clicked();
-    void on_savesDirButton_clicked();
-    void on_binDirButton_clicked();
-    void on_dataDirButton_clicked();
+    void downloadsDirButton_clicked();
+    void savesDirButton_clicked();
+    void binDirButton_clicked();
+    void dataDirButton_clicked();
 
 private:
     Ui::SettingsWindow *ui;
