@@ -93,7 +93,7 @@
         <translation>Найти .ipk файл...</translation>
     </message>
     <message>
-        <location filename="../src/ui/findipkwindow.ui" line="34"/>
+        <location filename="../src/ui/findipkwindow.ui" line="29"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -102,12 +102,16 @@ p, li { white-space: pre-wrap; }
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/ui/findipkwindow.ui" line="83"/>
-        <source>Find .IPK on Internet...</source>
-        <translation>Найти .ipk в интернете...</translation>
+        <location filename="../src/ui/findipkwindow.ui" line="78"/>
+        <source>Open Game Website</source>
+        <translation>Открыть сайт игры</translation>
     </message>
     <message>
-        <location filename="../src/ui/findipkwindow.ui" line="102"/>
+        <source>Find .IPK on Internet...</source>
+        <translation type="obsolete">Найти .ipk в интернете...</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/findipkwindow.ui" line="97"/>
         <source>Locate .IPK file in different folder...</source>
         <translation>Найти .ipk в другой папке...</translation>
     </message>
@@ -122,22 +126,22 @@ p, li { white-space: pre-wrap; }
         <translation>и сохранить его в каталог /Downloads.</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="41"/>
+        <location filename="../src/findipkwindow.cpp" line="40"/>
         <source>If you&apos;re sure that you downloaded right .ipk file to MyDocs/Downloads directory, then click &quot;Done&quot;</source>
         <translation>Если вы уверены, что скачали правильный файл в папку /Downloads, тогда нажмите &quot;Вернуться&quot;</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="44"/>
+        <location filename="../src/findipkwindow.cpp" line="43"/>
         <source>Done</source>
         <translation>Вернуться</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="51"/>
+        <location filename="../src/findipkwindow.cpp" line="50"/>
         <source>Locate IPK File</source>
         <translation>Найти .ipk файл</translation>
     </message>
     <message>
-        <location filename="../src/findipkwindow.cpp" line="53"/>
+        <location filename="../src/findipkwindow.cpp" line="52"/>
         <source>IPK (*.ipk)</source>
         <translation></translation>
     </message>
@@ -150,12 +154,17 @@ p, li { white-space: pre-wrap; }
         <translation>Установка</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="37"/>
+        <location filename="../src/installwindow.cpp" line="18"/>
+        <source>Install game</source>
+        <translation>Установка игры</translation>
+    </message>
+    <message>
+        <location filename="../src/installwindow.cpp" line="38"/>
         <source>Notes</source>
         <translation>Заметки</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="41"/>
+        <location filename="../src/installwindow.cpp" line="42"/>
         <source>Game installed!</source>
         <translation>Игра установлена!</translation>
     </message>
@@ -164,90 +173,95 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Выполнение послеустановочных команд</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="93"/>
+        <location filename="../src/installwindow.cpp" line="98"/>
         <source>Prepare desktop shortcut</source>
         <translation>Подготовка иконок</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="102"/>
-        <location filename="../src/installwindow.cpp" line="110"/>
-        <location filename="../src/installwindow.cpp" line="116"/>
+        <location filename="../src/installwindow.cpp" line="107"/>
+        <location filename="../src/installwindow.cpp" line="115"/>
+        <location filename="../src/installwindow.cpp" line="121"/>
         <source>Cannot create directory %1</source>
         <translation>Невозможно создать каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="133"/>
+        <location filename="../src/installwindow.cpp" line="138"/>
         <source>Cannot copy icon </source>
         <translation>Невозможно скопировать иконку </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="168"/>
+        <location filename="../src/installwindow.cpp" line="173"/>
         <source>Cannot create .desktop file </source>
         <translation>Невозможно создать .desktop файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="181"/>
+        <location filename="../src/installwindow.cpp" line="186"/>
         <source>Cannot create DBUS .service file </source>
         <translation>Невозможно создать dbus .service файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="197"/>
+        <location filename="../src/installwindow.cpp" line="202"/>
         <source>Prepare files and symlinks</source>
         <translation>Подготовка файлов и ссылок</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="211"/>
+        <location filename="../src/installwindow.cpp" line="216"/>
         <source>Cannot copy binary file </source>
         <translation>Невозможно скопировать бинарный файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="245"/>
+        <location filename="../src/installwindow.cpp" line="252"/>
         <source>Unpack archive (it may take a while)</source>
         <translation>Распаковка архива (может занять немного времени)</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="264"/>
+        <location filename="../src/installwindow.cpp" line="272"/>
         <source>Cannot unpack archive:&lt;br /&gt;</source>
         <translation>Невозможно распаковать архив:&lt;br /&gt;</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="278"/>
+        <location filename="../src/installwindow.cpp" line="287"/>
         <source>Prepare directories</source>
         <translation>Подготовка каталогов</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="286"/>
+        <location filename="../src/installwindow.cpp" line="295"/>
         <source>Main property not found in Json: </source>
         <translation>Поле Main не найдено в appinfo.json: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="307"/>
-        <location filename="../src/installwindow.cpp" line="311"/>
+        <location filename="../src/installwindow.cpp" line="316"/>
+        <location filename="../src/installwindow.cpp" line="320"/>
         <source>Can&apos;t create directory %1</source>
         <translation>Не могу создать каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="325"/>
+        <location filename="../src/installwindow.cpp" line="334"/>
         <source>Extracting game info</source>
         <translation>Извлечение информации об игре</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="345"/>
+        <location filename="../src/installwindow.cpp" line="354"/>
         <source>Cannot parse JSON: </source>
         <translation>Ошибка разбора JSON: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="352"/>
+        <location filename="../src/installwindow.cpp" line="361"/>
         <source>Error parsing appinfo.json!</source>
         <translation>Ошибка парсера JSON!</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="369"/>
+        <location filename="../src/installwindow.cpp" line="365"/>
+        <source> by </source>
+        <translation> от </translation>
+    </message>
+    <message>
+        <location filename="../src/installwindow.cpp" line="378"/>
         <source>Checking available space</source>
         <translation>Проверка свободного места</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="380"/>
+        <location filename="../src/installwindow.cpp" line="389"/>
         <source>Available free space in /home/user/MyDocs directory is %1MB, but the game requires %2MB!</source>
         <translation>Доступное место в MyDocs каталоге - %1МБ, но игре нужно %2МБ!</translation>
     </message>
@@ -280,7 +294,7 @@ p, li { white-space: pre-wrap; }
     <message numerus="yes">
         <location filename="../src/mainwindow.cpp" line="90"/>
         <source>, %n games installed</source>
-        <translation type="unfinished">
+        <translation>
             <numerusform>, %n игра установлена</numerusform>
             <numerusform>, %n игры установлено</numerusform>
             <numerusform>, %n игр установлено</numerusform>
@@ -378,6 +392,11 @@ p, li { white-space: pre-wrap; }
         <source>Game installed</source>
         <translation>Игра установлена</translation>
     </message>
+    <message>
+        <location filename="../src/managewindow.cpp" line="180"/>
+        <source> (version %1)</source>
+        <translation> (версия %1)</translation>
+    </message>
     <message>
         <location filename="../src/managewindow.cpp" line="188"/>
         <source>IPK file</source>
@@ -523,42 +542,42 @@ p, li { white-space: pre-wrap; }
         <translation>По умолчанию</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="54"/>
+        <location filename="../src/settingswindow.cpp" line="59"/>
         <source>Downloads Dir</source>
         <translation>Каталог с .ipk файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="55"/>
+        <location filename="../src/settingswindow.cpp" line="60"/>
         <source>Data Dir</source>
         <translation>Каталог с файлами данных</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="56"/>
+        <location filename="../src/settingswindow.cpp" line="61"/>
         <source>Bin Dir</source>
         <translation>Каталог с бинарными файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="57"/>
+        <location filename="../src/settingswindow.cpp" line="62"/>
         <source>Saves Dir</source>
         <translation>Каталог сэйвов</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="147"/>
+        <location filename="../src/settingswindow.cpp" line="152"/>
         <source>Downloads Directory</source>
         <translation>Каталог с .ipk файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="160"/>
+        <location filename="../src/settingswindow.cpp" line="165"/>
         <source>Saves Directory</source>
         <translation>Каталог с сэйвами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="172"/>
+        <location filename="../src/settingswindow.cpp" line="177"/>
         <source>Binary Directory</source>
         <translation>Каталог с бинарными файлами</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="184"/>
+        <location filename="../src/settingswindow.cpp" line="189"/>
         <source>Game Data Directory</source>
         <translation>Каталог с файлами данных игр</translation>
     </message>
@@ -571,50 +590,55 @@ p, li { white-space: pre-wrap; }
         <translation>Удаление</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="36"/>
+        <location filename="../src/uninstallwindow.cpp" line="16"/>
+        <source>Uninstall game</source>
+        <translation>Удаление игры</translation>
+    </message>
+    <message>
+        <location filename="../src/uninstallwindow.cpp" line="37"/>
         <source>Cleaning up</source>
         <translation>Очистка</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="47"/>
-        <location filename="../src/uninstallwindow.cpp" line="53"/>
-        <location filename="../src/uninstallwindow.cpp" line="59"/>
+        <location filename="../src/uninstallwindow.cpp" line="48"/>
+        <location filename="../src/uninstallwindow.cpp" line="54"/>
+        <location filename="../src/uninstallwindow.cpp" line="60"/>
         <source>Cannot delete file %1</source>
         <translation>Невозможно удалить файл %1</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="66"/>
+        <location filename="../src/uninstallwindow.cpp" line="67"/>
         <source>Game uninstalled successfully!</source>
         <translation>Игра успешно удалена!</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="79"/>
+        <location filename="../src/uninstallwindow.cpp" line="80"/>
         <source>Removing game</source>
         <translation>Удаление игры</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="84"/>
-        <location filename="../src/uninstallwindow.cpp" line="90"/>
+        <location filename="../src/uninstallwindow.cpp" line="85"/>
+        <location filename="../src/uninstallwindow.cpp" line="91"/>
         <source>Cannot delete dir %1</source>
         <translation>Невозможно удалить каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="104"/>
+        <location filename="../src/uninstallwindow.cpp" line="105"/>
         <source>Checking directories</source>
         <translation>Проверка каталогов</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="107"/>
+        <location filename="../src/uninstallwindow.cpp" line="108"/>
         <source>Game Title is not found. That means some manual edit or program bug.</source>
         <translation>Не могу найти название игры. Это означает, что файл конфигурации был изменен вручную или ошибку программы.</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="117"/>
+        <location filename="../src/uninstallwindow.cpp" line="118"/>
         <source>Data directory %1 does not exist.&lt;br /&gt;This means some manual intervention or the program bug.</source>
         <translation>Каталог с данными %1 не существует&lt;br /&gt;Это означает ручное вмешательство или ошибку программы.</translation>
     </message>
     <message>
-        <location filename="../src/uninstallwindow.cpp" line="124"/>
+        <location filename="../src/uninstallwindow.cpp" line="125"/>
         <source>Bin directory %1 does not exist.&lt;br /&gt;This means some manual intervention or the program bug.</source>
         <translation>Каталог с бинарными данными %1 не найден.&lt;br /&gt;Это означает ручное вмешательство или ошибку программы.</translation>
     </message>
